==> 0.0.1%2B1.tar.gz: lib/models/IR5PtrDevice.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Route2PtrLnk.dart" show IR5Route2PtrLnk;

// --------------------------------------------------------------------------------
part 'IR5PtrDevice.g.dart';
/** Printers */

@JsonSerializable(explicitToJson: true)
class IR5PtrDevice {
  IR5PtrDevice({
    required this.Num,
    required this.Nom,
    required this.Flags,
    required this.Interface,
    required this.CtrlMode,
    required this.Description,
    required this.PC_Name,
    required this.PORT_Name,
    required this.Driver,
    required this.DriverClass,
    required this.DriverName,
    required this.DriverDescr,
    required this.Layouts,
    required this.LayoutsName,
    required this.LayoutsDescr,
    required this.RedirectManual,
    required this.Redirect,
    required this.RedirectTimeOut,
    required this.Status_Flags,
    required this.Routes,
    required this.PtrLinks,
  });

  factory IR5PtrDevice.fromJson(Map<String, dynamic>? json) => _$IR5PtrDeviceFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PtrDeviceToJson(this);

  @JsonKey(defaultValue: 0)
  final num Num;
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Ptr Flags
   *   Bit 01 : Poubelle
   *   Bit 03 : AddNoLogo
   *   Bit 04 : ProdDoBeep
   *   Bit 10 : TicketSeparated
   *   Bit 11 : TicketFullSeparated
   *   Bit 20 : RedirectForced
   *   Bit 21 : RedirectAuto
   *   Bit 22 : DelayedNoMsg
   *   Bit 23 : RedirectForcedNoMsg
   *   Bit 24 : RedirectAutoNoMsg
   *   Bit 30 : EpsonT88
   *   Bit 31 : EpsonTM200
   *   Bit 32 : EpsonStar
   *   Bit 33 : EpsonBixolon
   *   Bit 34 : EpsonT88Big
   *   Bit 35 : EpsonTMJ7500
   *   Bit 40 : WindowEpsonT88
   *   Bit 41 : WindowEpsonTM200
   *   Bit 49 : WindowCourierNew
   *   Bit 50 : SerialCheckDSRFlag
   *   Bit 59 : RawJSON
   */
  @JsonKey(defaultValue: 0)
  final num Flags;
  @JsonKey(defaultValue: '')
  final String Interface;
  @JsonKey(defaultValue: '')
  final String CtrlMode;
  @JsonKey(defaultValue: '')
  final String Description;
  @JsonKey(defaultValue: '')
  final String PC_Name;
  @JsonKey(defaultValue: '')
  final String PORT_Name;
  @JsonKey(defaultValue: 0)
  final num Driver;
  @JsonKey(defaultValue: '')
  final String DriverClass;
  @JsonKey(defaultValue: '')
  final String DriverName;
  @JsonKey(defaultValue: '')
  final String DriverDescr;
  @JsonKey(defaultValue: 0)
  final num Layouts;
  @JsonKey(defaultValue: '')
  final String LayoutsName;
  @JsonKey(defaultValue: '')
  final String LayoutsDescr;
  @JsonKey(defaultValue: 0)
  final num RedirectManual;
  @JsonKey(defaultValue: 0)
  final num Redirect;
  @JsonKey(defaultValue: 0)
  final num RedirectTimeOut;

  /** Printer Status Flag
   *     psfOffLine,
   *     psfTiroirOpen,
   *     psfCoverOpen,
   *     psfFeedPaperError,
   *     psfPaperError,
   */
  @JsonKey(defaultValue: 0)
  final num Status_Flags;
  @JsonKey(defaultValue: [])
  final List<num> Routes;
  @JsonKey(defaultValue: [])
  final List<IR5Route2PtrLnk> PtrLinks;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5PtrDevice.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Route2PtrLnk.dart" show IR5Route2PtrLnk;

// --------------------------------------------------------------------------------
part 'IR5PtrDevice.g.dart';
/** Printers */

@JsonSerializable(explicitToJson: true)
class IR5PtrDevice {
  IR5PtrDevice({
    required this.Num,
    required this.Nom,
    required this.Flags,
    required this.Interface,
    required this.CtrlMode,
    required this.Description,
    required this.PC_Name,
    required this.PORT_Name,
    required this.Driver,
    required this.DriverClass,
    required this.DriverName,
    required this.DriverDescr,
    required this.Layouts,
    required this.LayoutsName,
    required this.LayoutsDescr,
    required this.RedirectManual,
    required this.Redirect,
    required this.RedirectTimeOut,
    required this.Status_Flags,
    required this.Routes,
    required this.PtrLinks,
  });

  factory IR5PtrDevice.fromJson(Map<String, dynamic>? json) =>
      _$IR5PtrDeviceFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PtrDeviceToJson(this);

  @JsonKey(defaultValue: 0)
  final num Num;
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Ptr Flags
   *   Bit 01 : Poubelle
   *   Bit 03 : AddNoLogo
   *   Bit 04 : ProdDoBeep
   *   Bit 10 : TicketSeparated
   *   Bit 11 : TicketFullSeparated
   *   Bit 20 : RedirectForced
   *   Bit 21 : RedirectAuto
   *   Bit 22 : DelayedNoMsg
   *   Bit 23 : RedirectForcedNoMsg
   *   Bit 24 : RedirectAutoNoMsg
   *   Bit 30 : EpsonT88
   *   Bit 31 : EpsonTM200
   *   Bit 32 : EpsonStar
   *   Bit 33 : EpsonBixolon
   *   Bit 34 : EpsonT88Big
   *   Bit 35 : EpsonTMJ7500
   *   Bit 40 : WindowEpsonT88
   *   Bit 41 : WindowEpsonTM200
   *   Bit 49 : WindowCourierNew
   *   Bit 50 : SerialCheckDSRFlag
   *   Bit 59 : RawJSON
   */
  @JsonKey(defaultValue: 0)
  final num Flags;
  @JsonKey(defaultValue: '')
  final String Interface;
  @JsonKey(defaultValue: '')
  final String CtrlMode;
  @JsonKey(defaultValue: '')
  final String Description;
  @JsonKey(defaultValue: '')
  final String PC_Name;
  @JsonKey(defaultValue: '')
  final String PORT_Name;
  @JsonKey(defaultValue: 0)
  final num Driver;
  @JsonKey(defaultValue: '')
  final String DriverClass;
  @JsonKey(defaultValue: '')
  final String DriverName;
  @JsonKey(defaultValue: '')
  final String DriverDescr;
  @JsonKey(defaultValue: 0)
  final num Layouts;
  @JsonKey(defaultValue: '')
  final String LayoutsName;
  @JsonKey(defaultValue: '')
  final String LayoutsDescr;
  @JsonKey(defaultValue: 0)
  final num RedirectManual;
  @JsonKey(defaultValue: 0)
  final num Redirect;
  @JsonKey(defaultValue: 0)
  final num RedirectTimeOut;

  /** Printer Status Flag
   *     psfOffLine,
   *     psfTiroirOpen,
   *     psfCoverOpen,
   *     psfFeedPaperError,
   *     psfPaperError,
   */
  @JsonKey(defaultValue: 0)
  final num Status_Flags;
  @JsonKey(defaultValue: [])
  final List<num> Routes;
  @JsonKey(defaultValue: [])
  final List<IR5Route2PtrLnk> PtrLinks;
}
